@@ -24,16 +24,24 @@ import subprocess
 import sys, os
 import logging
 import glob
+import functools
+
+from multiprocessing import Pool
+
+# Ugly hack to pass in object method to the multiprocessing library
+# From http://www.rueckstiess.net/research/snippets/show/ca1d7d90
+# Basically gets passed in a pair of (self, arg), and calls the method
+def unwrap_self(arg, **kwarg):
+    return PyPreprocess._run_preprocess(*arg, **kwarg)
 
 
 class PyPreprocess(object):
     """Class to wrap all the ImageMagick convert calls"""
-    def __init__(self):
+    def __init__(self, config):
         self.msgs = {
                 'CV_FAILED': 'convert execution failed',
             }
-
-
+        self.threads = config.get('threads', 4)
 
     def _warn(self, msg): # pragma: no cover
         print("WARNING: %s" % msg)
@@ -55,36 +63,45 @@ class PyPreprocess(object):
         basename, filext = os.path.splitext(in_filename)
         out_filename = '%s_preprocess%s' % (basename, filext)
         #-respect-parenthesis \( -clone 0 -colorspace gray -negate -lat 15x5+5% -contrast-stretch 0 \) -compose copy_opacity -composite -opaque none +matte -modulate 100,50 -adaptive-blur 2.0 -sharpen 0x1 
+        # When using Windows, can't use backslash parenthesis in the shell, so omit the backslash
+        if str(os.name) == 'nt':
+            backslash = ''
+        else:
+            backslash = '\\'
+
         c = ['convert',
-                "'%s'" % in_filename,
+                '"%s"' % in_filename,
                 '-respect-parenthesis',
                 #'\\( $setcspace -colorspace gray -type grayscale \\)',
-                '\\(',
+                backslash+'(',
                 '-clone 0',
-                '-colorspace gray -negate -lat 15x15+5\% -contrast-stretch 0 \\) -compose copy_opacity -composite -opaque none +matte -modulate 100,100',
+                '-colorspace gray -negate -lat 15x15+5\% -contrast-stretch 0',
+                backslash+') -compose copy_opacity -composite -opaque none +matte -modulate 100,100',
                 #'-adaptive-blur 1.0',
                 '-blur 1x1',
                 #'-selective-blur 4x4+5%',
                 '-adaptive-sharpen 0x2',
                 '-negate -define morphology:compose=darken -morphology Thinning Rectangle:1x30+0+0 -negate ',  # Removes vertical lines >=60 pixes, reduces widht of >30 (oherwise tesseract completely ignores text close to vertical lines in a table)
-                "'%s'" % (out_filename)
+                '"%s"' % (out_filename)
                 ]
-        logging.info("Preprocessing image for better OCR")
+        logging.info("Preprocessing image %s for better OCR" % in_filename)
         res = self.cmd(c)
         if res is None:
             return in_filename
         else:
             return out_filename
 
-
-
     def preprocess(self, in_filenames):
         fns = in_filenames
-        preprocessed_filenames = []
-        for fn in fns:
-            out_fn = self._run_preprocess(fn)
-            logging.debug("Created %s" % out_fn)
-            preprocessed_filenames.append(out_fn)
+
+        pool = Pool(processes=self.threads)
+        logging.info("Starting preprocessing parallel execution")
+        preprocessed_filenames = pool.map(unwrap_self,zip([self]*len(fns),fns))
+        pool.close()
+        pool.join()
+        logging.info ("Completed preprocessing")
         return preprocessed_filenames
 
 
+
+
