@@ -18,7 +18,7 @@ class TestGS:
             Check that we have a exe on windows
         """
         mock_os_name.__str__.return_value = 'nt'
-        p = P.PyGs()
+        p = P.PyGs({})
 
         assert 'gswin' in p.binary
 
@@ -30,7 +30,7 @@ class TestGS:
             Stupid test because Windows Tesseract only returns 3.02 instead of 3.02.02
         """
         mock_os_name.__str__.return_value = 'nt'
-        p = P.PyGs()
+        p = P.PyGs({})
 
         mock_subprocess.return_value = -1
         p.binary = 'gsblah.exe'
@@ -41,9 +41,9 @@ class TestGS:
         assert p.msgs['GS_FAILED'] in out
 
     def test_gs_pdf_missing(self, capsys):
-        p = P.PyGs()
+        p = P.PyGs({})
         with pytest.raises(SystemExit):
-            p.make_img_from_pdf("missing123.pdf", "")
+            p.make_img_from_pdf("missing123.pdf")
         out,err = capsys.readouterr()
         assert p.msgs['GS_MISSING_PDF'] in out
 
