@@ -12,7 +12,7 @@ class TestTesseract:
     @pytest.mark.skipif(os.name=='nt', reason='Does not work on Windows')
     def test_version_shorter_older(self):
         with patch("subprocess.check_output") as mock_subprocess:
-            p = P.PyTesseract()
+            p = P.PyTesseract({})
             p.required = "3.02.02"
             mock_subprocess.return_value = """tesseract 3.02"""
             uptodate,ver = p._is_version_uptodate()
@@ -20,7 +20,7 @@ class TestTesseract:
 
     def test_version_minor_older(self):
         with patch("subprocess.check_output") as mock_subprocess:
-            p = P.PyTesseract()
+            p = P.PyTesseract({})
             p.required = "3.02.02"
             mock_subprocess.return_value = """tesseract 3.02.01"""
             uptodate,ver = p._is_version_uptodate()
@@ -28,7 +28,7 @@ class TestTesseract:
 
     def test_version_major_older(self):
         with patch("subprocess.check_output") as mock_subprocess:
-            p = P.PyTesseract()
+            p = P.PyTesseract({})
             p.required = "3.02.02"
             mock_subprocess.return_value = """tesseract 2.03.03"""
             uptodate,ver = p._is_version_uptodate()
@@ -37,7 +37,7 @@ class TestTesseract:
     @pytest.mark.skipif(os.name=='nt', reason='Does not work on Windows')
     def test_version_major_equal(self):
         with patch("subprocess.check_output") as mock_subprocess:
-            p = P.PyTesseract()
+            p = P.PyTesseract({})
             p.required = "3.02.02"
             mock_subprocess.return_value = """tesseract 3.02.02"""
             uptodate,ver = p._is_version_uptodate()
@@ -45,7 +45,7 @@ class TestTesseract:
 
     def test_version_major_newer(self):
         with patch("subprocess.check_output") as mock_subprocess:
-            p = P.PyTesseract()
+            p = P.PyTesseract({})
             p.required = "3.02.02"
 
             mock_subprocess.return_value = """tesseract 4.01"""
@@ -54,7 +54,7 @@ class TestTesseract:
 
     def test_version_minor_newer(self):
         with patch("subprocess.check_output") as mock_subprocess:
-            p = P.PyTesseract()
+            p = P.PyTesseract({})
             p.required = "3.01.02"
 
             mock_subprocess.return_value = """tesseract 3.02"""
@@ -63,7 +63,7 @@ class TestTesseract:
 
 
     def test_tesseract_presence(self, capsys):
-        p = P.PyTesseract()
+        p = P.PyTesseract({})
         p.binary = "tesserac" # Misspell it and make sure we get an error
         with pytest.raises(SystemExit):
             p._is_version_uptodate()
@@ -71,7 +71,7 @@ class TestTesseract:
         assert p.msgs['TS_MISSING'] in out
 
     def test_tesseract_version(self, capsys):
-        p = P.PyTesseract()
+        p = P.PyTesseract({})
         p.required = "100"
         with pytest.raises(SystemExit):
             p.make_hocr_from_pnms("")
@@ -79,7 +79,7 @@ class TestTesseract:
         assert p.msgs['TS_VERSION'] in out
 
     def test_tiff_file_check(self, capsys):
-        p = P.PyTesseract()
+        p = P.PyTesseract({})
         with pytest.raises(SystemExit):
             p.make_hocr_from_pnm("DUMMY_NOTPRESENT.tiff")
         out, err = capsys.readouterr()
@@ -92,7 +92,7 @@ class TestTesseract:
             Stupid test because Windows Tesseract only returns 3.02 instead of 3.02.02
         """
         mock_os_name.__str__.return_value = 'nt'
-        p = P.PyTesseract()
+        p = P.PyTesseract({})
         p.required = "3.02.02"
 
         mock_subprocess.return_value = """tesseract 3.02"""
@@ -104,7 +104,7 @@ class TestTesseract:
     @patch('pypdfocr.pypdfocr_tesseract.os.path.exists')
     def test_force_Nt(self, mock_os_path_exists, mock_os_name, mock_uptodate, capsys):
         mock_os_name.__str__.return_value = 'nt'
-        p = P.PyTesseract()
+        p = P.PyTesseract({})
         assert ('tesseract.exe' in p.binary)
 
         mock_os_path_exists.return_value = True 
@@ -124,7 +124,7 @@ class TestTesseract:
             Get all the checks past and make sure we report the case where tesseract returns a non-zero status
         """
         mock_os_name.__str__.return_value = 'nt'
-        p = P.PyTesseract()
+        p = P.PyTesseract({})
         assert ('tesseract.exe' in p.binary)
 
         mock_os_path_exists.return_value = True 
